@@ -3,7 +3,7 @@ import logging.config
 import os
 import traceback
 
-from config.sys_config import SysConfig
+from mag_tools.config.sys_config import SysConfig
 from mag_tools.model.log_type import LogType
 from mag_tools.utils.common.string_utils import StringUtils
 
@@ -11,27 +11,28 @@ from mag_tools.utils.common.string_utils import StringUtils
 class Logger:
     __instance = None
 
+    def __new__(cls, *args, **kwargs):
+        if not cls.__instance:
+            cls.__instance = super(Logger, cls).__new__(cls)
+        return cls.__instance
+
     def __init__(self):
         """
         初始化 Logger 实例，配置日志记录器和日志文件路径。
         """
-        log_dir = SysConfig.get('logDir')
+        log_dir = SysConfig().get('logDir')
         os.makedirs(log_dir, exist_ok=True)
 
-        logging.config.fileConfig(SysConfig.logging_conf(),
+        logging.config.fileConfig(SysConfig().logging_conf(),
                                   encoding='utf-8',
                                   defaults={'logdir': str(log_dir)})
 
         self.root_logger = logging.getLogger()
-
         self.frame_logger = logging.getLogger('frame')
-
+        self.dao_logger = logging.getLogger('dao')
         self.service_logger = logging.getLogger('service')
-
         self.performance_logger = logging.getLogger('performance')
 
-        Logger.__instance = self
-
     @classmethod
     def debug(cls, *args):
         """
@@ -41,10 +42,10 @@ class Logger:
         """
         if len(args) == 1:
             message = args[0]
-            cls.__logger().__debug(LogType.FRAME, message)
+            cls().__debug(LogType.FRAME, message)
         elif len(args) == 2:
             log_type, message = args
-            cls.__logger().__debug(log_type, message)
+            cls().__debug(log_type, message)
         else:
             raise ValueError("Invalid number of arguments")
 
@@ -57,18 +58,18 @@ class Logger:
         """
         if len(args) == 1:
             message = args[0]
-            cls.__logger().__info(LogType.FRAME, message)
+            cls().__info(LogType.FRAME, message)
         elif len(args) == 2:
             logger_type, message = args
-            cls.__logger().__info(logger_type, message)
+            cls().__info(logger_type, message)
         elif len(args) == 3:
             logger_type, message, is_highlight = args
             if is_highlight:
-                cls.__logger().__info(logger_type, '*' * (StringUtils.get_print_width(message) + 8))
-                cls.__logger().__info(logger_type, f'*** {message} ***')
-                cls.__logger().__info(logger_type, '*' * (StringUtils.get_print_width(message) + 8))
+                cls().__info(logger_type, '*' * (StringUtils.get_print_width(message) + 8))
+                cls().__info(logger_type, f'*** {message} ***')
+                cls().__info(logger_type, '*' * (StringUtils.get_print_width(message) + 8))
             else:
-                cls.__logger().__info(logger_type, message)
+                cls().__info(logger_type, message)
         else:
             raise ValueError("Invalid number of arguments")
 
@@ -81,10 +82,10 @@ class Logger:
         """
         if len(args) == 1:
             message = args[0]
-            cls.__logger().__warning(LogType.FRAME, message)
+            cls().__warning(LogType.FRAME, message)
         elif len(args) == 2:
             logger_type, message = args
-            cls.__logger().__warning(logger_type, message)
+            cls().__warning(logger_type, message)
         else:
             raise ValueError("Invalid number of arguments")
 
@@ -97,19 +98,27 @@ class Logger:
         """
         if len(args) == 1:
             message = str(args[0]) if isinstance(args[0], Exception) else args[0]
-            cls.__logger().__error(LogType.FRAME, message)
+            cls().__error(LogType.FRAME, message)
         elif len(args) == 2:
             logger_type, message = args
             message = str(message) if isinstance(message, Exception) else message
-            cls.__logger().__error(logger_type, message)
+            cls().__error(logger_type, message)
         else:
             raise ValueError("Invalid number of arguments")
 
     @classmethod
-    def __logger(cls):
-        if cls.__instance is None:
-            cls()
-        return cls.__instance
+    def throw(cls, *args):
+        Logger.error(args)
+
+        if len(args) == 1:
+            message = str(args[0]) if isinstance(args[0], Exception) else args[0]
+        elif len(args) == 2:
+            logger_type, message = args
+            message = str(message) if isinstance(message, Exception) else message
+        else:
+            raise ValueError("Invalid number of arguments")
+
+        raise message
 
     def __debug(self, logger_type: LogType, message: str):
         """
@@ -122,6 +131,8 @@ class Logger:
 
         if logger_type == LogType.FRAME:
             self.frame_logger.debug(message)
+        elif logger_type == LogType.DAO:
+            self.dao_logger.debug(message)
         elif logger_type == LogType.SERVICE:
             self.service_logger.debug(message)
         elif logger_type == LogType.PERFORMANCE:
@@ -138,6 +149,8 @@ class Logger:
 
         if logger_type == LogType.FRAME:
             self.frame_logger.info(message)
+        elif logger_type == LogType.DAO:
+            self.dao_logger.info(message)
         elif logger_type == LogType.SERVICE:
             self.service_logger.info(message)
         elif logger_type == LogType.PERFORMANCE:
@@ -154,6 +167,8 @@ class Logger:
 
         if logger_type == LogType.FRAME:
             self.frame_logger.warning(message)
+        elif logger_type == LogType.DAO:
+            self.dao_logger.warning(message)
         elif logger_type == LogType.SERVICE:
             self.service_logger.warning(message)
         elif logger_type == LogType.PERFORMANCE:
@@ -171,6 +186,8 @@ class Logger:
 
         if logger_type == LogType.FRAME:
             self.frame_logger.error(error_message)
+        elif logger_type == LogType.DAO:
+            self.dao_logger.error(error_message)
         elif logger_type == LogType.SERVICE:
             self.service_logger.error(error_message)
         elif logger_type == LogType.PERFORMANCE:
